# UI/UX Feedback

**ID:** Feedback-20260307-094938
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-07 09:50:32

## Selected Elements

- `{'selector': 'button.action-btn:nth-of-type(1)', 'parents': ['div.workflow-panel-body', 'div.actions-area', 'div.action-group', 'div.actions-grid']}`

## Feedback

after finish the action work, it's turn into green, but the in progress animation should stop after it's complete

## Screenshot

![Screenshot](./page-screenshot.png)
